Module api

Module api 

👎Deprecated since 0.0.6:

libyml is unmaintained. Migrate to a maintained alternative (unsafe-libyaml, yaml-rust2, or noyalib). See MIGRATION.md.

API-surface helpers. Re-exported from the crate root for source compatibility with libyml ≤ 0.0.5’s libyml::api module.

Functions

yaml_alias_event_initialize
Create an ALIAS event.
yaml_emitter_delete
Destroy an emitter.
yaml_emitter_initialize
Initialize an emitter.
yaml_emitter_set_break
Set the preferred line break.
yaml_emitter_set_canonical
Set if the output should be in the “canonical” format as in the YAML specification.
yaml_emitter_set_encoding
Set the output encoding.
yaml_emitter_set_indent
Set the indentation increment.
yaml_emitter_set_output
Set a generic output handler.
yaml_emitter_set_output_string
Set a string output.
yaml_emitter_set_unicode
Set if unescaped non-ASCII characters are allowed.
yaml_emitter_set_width
Set the preferred line width. -1 means unlimited.
yaml_mapping_end_event_initialize
Create a MAPPING-END event.
yaml_mapping_start_event_initialize
Create a MAPPING-START event.
yaml_parser_set_encoding
Set the source encoding.
yaml_parser_set_input
Set a generic input handler.
yaml_parser_set_input_string
Set a string input.
yaml_scalar_event_initialize
Create a SCALAR event.
yaml_sequence_end_event_initialize
Create a SEQUENCE-END event.
yaml_sequence_start_event_initialize
Create a SEQUENCE-START event.
yaml_stream_end_event_initialize
Create the STREAM-END event.
yaml_stream_start_event_initialize
Create the STREAM-START event.
yaml_token_delete
Free any memory allocated for a token object.